#!/bedrock/libexec/busybox sh

. /bedrock/share/common-code
echo "Fetching latest commits from repository..."
if [ -d /bedrock/cache/bedrocklinux-userland ]; then
	less_lethal_rm_rf /bedrock/cache/bedrocklinux-userland
fi
mkdir -p /bedrock/cache
cd /bedrock/cache
git clone https://github.com/bedrocklinux/bedrocklinux-userland
cd bedrocklinux-userland
git checkout 0.7 -q
current_version="$(awk '{print$3}' </bedrock/etc/bedrock-release)"
newest_version=$(awk -F= '/^VERSION=/{print$2}' Makefile | sed 's/[a-z].*$//')git$(git log | grep -c "^commit") 
echo "Current Version: ${current_version}"
echo "Newest Version: ${newest_version}"
if ver_cmp_first_newer ${current_version} ${newest_version}; then
	if [ ${#current_version} -lt ${#newest_version} ]; then
		echo "Building for the first time. Building Bedrock Linux version ${newest_version}"
	else
		echo "Up to date with the latest commit, nothing to do."
		exit_success
	fi
else
	echo "Building Bedrock Linux version ${newest_version}"
fi
# Start the build process
make clean
if ! grep -q BEDROCK_VERSION Makefile; then # Fix bug with building BusyBox
    sed 's/VERSION/BEDROCK_VERSION/g' Makefile > Makefile-new
    mv Makefile-new Makefile
fi
make SKIPSIGN=true -j $(nproc) BEDROCK_VERSION="${newest_version}"
/bedrock/libexec/busybox sh "bedrock-linux-${newest_version}-$(uname -m).sh" --force-update
# Maybe clean up here in the future
echo "If there were no errors up to this point, then everything has gone smoothly. Ignore the following 2 errors!"
exit_success